# yapymake

A (mostly) [POSIX-compatible](https://pubs.opengroup.org/onlinepubs/9699919799/utilities/make.html) make implemented in Python.

## conformance

- internationalization (`LANG`/`LC_ALL`/`LC_CTYPE`/`LC_MESSAGES`) not implemented
- XSI conformance (SCCS integration) not implemented
- signal handling not implemented
- library handling not implemented
- some POSIX-specified features are pending (search `TODO` for a list)
- builtin macro `MAKE` is defined as `sys.argv[0]` (i.e. however you invoked `yapymake`)

## status

there are no automated tests whatsoever, so if this works, consider that a coincidence.
that said, I test manually on complicated projects, and the current record for most complex project which builds successfully with yapymake is Tcl.

## changelog

### v0.2.0 - 2021-03-25

- implement GNU-style VPATH

### v0.1.0 - 2021-03-25

- initial release

## license

Released under the [Indie Code Catalog Standard Deal](https://indiecc.com/deal/3.0.0), version 3.0.0 or later.

Commercial licenses are available for purchase [through Indie Code Catalog](https://indiecc.com/~boringcactus/yapymake).
